@@ -1,6 +1,6 @@
 /*
  *
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -28,7 +28,7 @@ typedef struct _zel_tracer_handle_t *zel_tracer_handle_t;
 /// Callbacks for APIs included in spec 1.0 are contained in ze_api.helper
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeDriverGetExtensionFunctionAddress 
+/// @brief Callback function parameters for zeDriverGetExtensionFunctionAddress
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -41,7 +41,7 @@ typedef struct _ze_driver_get_extension_function_address_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeDriverGetExtensionFunctionAddress 
+/// @brief Callback function-pointer for zeDriverGetExtensionFunctionAddress
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -55,7 +55,7 @@ typedef void (ZE_APICALL *ze_pfnDriverGetExtensionFunctionAddressCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeDeviceGetGlobalTimestamps 
+/// @brief Callback function parameters for zeDeviceGetGlobalTimestamps
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -68,7 +68,7 @@ typedef struct _ze_device_get_global_timestamps_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeDeviceGetGlobalTimestamps 
+/// @brief Callback function-pointer for zeDeviceGetGlobalTimestamps
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -82,7 +82,7 @@ typedef void (ZE_APICALL *ze_pfnDeviceGetGlobalTimestampsCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeDeviceReserveCacheExt 
+/// @brief Callback function parameters for zeDeviceReserveCacheExt
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -95,7 +95,7 @@ typedef struct _ze_device_reserve_cache_ext_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeDeviceReserveCacheExt 
+/// @brief Callback function-pointer for zeDeviceReserveCacheExt
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -109,7 +109,7 @@ typedef void (ZE_APICALL *ze_pfnDeviceReserveCacheExtCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeDeviceSetCacheAdviceExt 
+/// @brief Callback function parameters for zeDeviceSetCacheAdviceExt
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -123,7 +123,7 @@ typedef struct _ze_device_set_cache_advice_ext_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeDeviceSetCacheAdviceExt 
+/// @brief Callback function-pointer for zeDeviceSetCacheAdviceExt
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -137,7 +137,59 @@ typedef void (ZE_APICALL *ze_pfnDeviceSetCacheAdviceExtCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeContextCreateEx 
+/// @brief Callback function parameters for zeDevicePciGetPropertiesExt
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_device_pci_get_properties_ext_params_t
+{
+    ze_device_handle_t* phDevice;
+    ze_pci_ext_properties_t** ppPciProperties;
+} ze_device_pci_get_properties_ext_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeDevicePciGetPropertiesExt
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnDevicePciGetPropertiesExtCb_t)(
+    ze_device_pci_get_properties_ext_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeDeviceGetFabricVertexExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_device_get_fabric_vertex_exp_params_t
+{
+    ze_device_handle_t* phDevice;
+    ze_fabric_vertex_handle_t** pphVertex;
+} ze_device_get_fabric_vertex_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeDeviceGetFabricVertexExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnDeviceGetFabricVertexExpCb_t)(
+    ze_device_get_fabric_vertex_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeContextCreateEx
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -152,7 +204,7 @@ typedef struct _ze_context_create_ex_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeContextCreateEx 
+/// @brief Callback function-pointer for zeContextCreateEx
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -166,7 +218,73 @@ typedef void (ZE_APICALL *ze_pfnContextCreateExCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeEventQueryTimestampsExp 
+/// @brief Callback function parameters for zeCommandListAppendImageCopyToMemoryExt
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_command_list_append_image_copy_to_memory_ext_params_t
+{
+    ze_command_list_handle_t* phCommandList;
+    void** pdstptr;
+    ze_image_handle_t* phSrcImage;
+    const ze_image_region_t** ppSrcRegion;
+    uint32_t* pdestRowPitch;
+    uint32_t* pdestSlicePitch;
+    ze_event_handle_t* phSignalEvent;
+    uint32_t* pnumWaitEvents;
+    ze_event_handle_t** pphWaitEvents;
+} ze_command_list_append_image_copy_to_memory_ext_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeCommandListAppendImageCopyToMemoryExt
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnCommandListAppendImageCopyToMemoryExtCb_t)(
+    ze_command_list_append_image_copy_to_memory_ext_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeCommandListAppendImageCopyFromMemoryExt
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_command_list_append_image_copy_from_memory_ext_params_t
+{
+    ze_command_list_handle_t* phCommandList;
+    ze_image_handle_t* phDstImage;
+    const void** psrcptr;
+    const ze_image_region_t** ppDstRegion;
+    uint32_t* psrcRowPitch;
+    uint32_t* psrcSlicePitch;
+    ze_event_handle_t* phSignalEvent;
+    uint32_t* pnumWaitEvents;
+    ze_event_handle_t** pphWaitEvents;
+} ze_command_list_append_image_copy_from_memory_ext_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeCommandListAppendImageCopyFromMemoryExt
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnCommandListAppendImageCopyFromMemoryExtCb_t)(
+    ze_command_list_append_image_copy_from_memory_ext_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeEventQueryTimestampsExp
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -180,7 +298,7 @@ typedef struct _ze_event_query_timestamps_exp_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeEventQueryTimestampsExp 
+/// @brief Callback function-pointer for zeEventQueryTimestampsExp
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -194,7 +312,7 @@ typedef void (ZE_APICALL *ze_pfnEventQueryTimestampsExpCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeImageGetMemoryPropertiesExp 
+/// @brief Callback function parameters for zeImageGetMemoryPropertiesExp
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -206,7 +324,7 @@ typedef struct _ze_image_get_memory_properties_exp_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeImageGetMemoryPropertiesExp 
+/// @brief Callback function-pointer for zeImageGetMemoryPropertiesExp
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -220,7 +338,7 @@ typedef void (ZE_APICALL *ze_pfnImageGetMemoryPropertiesExpCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeImageViewCreateExp 
+/// @brief Callback function parameters for zeImageViewCreateExp
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -235,7 +353,7 @@ typedef struct _ze_image_view_create_exp_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeImageViewCreateExp 
+/// @brief Callback function-pointer for zeImageViewCreateExp
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -249,7 +367,34 @@ typedef void (ZE_APICALL *ze_pfnImageViewCreateExpCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeKernelSetGlobalOffsetExp 
+/// @brief Callback function parameters for zeImageGetAllocPropertiesExt
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_image_get_alloc_properties_ext_params_t
+{
+    ze_context_handle_t* phContext;
+    ze_image_handle_t* phImage;
+    ze_image_allocation_ext_properties_t** ppImageAllocProperties;
+} ze_image_get_alloc_properties_ext_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeImageGetAllocPropertiesExt
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnImageGetAllocPropertiesExtCb_t)(
+    ze_image_get_alloc_properties_ext_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeKernelSetGlobalOffsetExp
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -263,7 +408,7 @@ typedef struct _ze_kernel_set_global_offset_exp_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeKernelSetGlobalOffsetExp 
+/// @brief Callback function-pointer for zeKernelSetGlobalOffsetExp
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -277,7 +422,7 @@ typedef void (ZE_APICALL *ze_pfnKernelSetGlobalOffsetExpCb_t)(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function parameters for zeKernelSchedulingHintExp 
+/// @brief Callback function parameters for zeKernelSchedulingHintExp
 /// @details Each entry is a pointer to the parameter passed to the function;
 ///     allowing the callback the ability to modify the parameter's value
 
@@ -289,7 +434,7 @@ typedef struct _ze_kernel_scheduling_hint_exp_params_t
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Callback function-pointer for zeKernelSchedulingHintExp 
+/// @brief Callback function-pointer for zeKernelSchedulingHintExp
 /// @param[in] params Parameters passed to this instance
 /// @param[in] result Return value
 /// @param[in] pTracerUserData Per-Tracer user data
@@ -302,6 +447,248 @@ typedef void (ZE_APICALL *ze_pfnKernelSchedulingHintExpCb_t)(
     void** ppTracerInstanceUserData
     );
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeMemFreeExt
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_mem_free_ext_params_t
+{
+    ze_context_handle_t* phContext;
+    const ze_memory_free_ext_desc_t** ppMemFreeDesc;
+    void** pptr;
+} ze_mem_free_ext_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeMemFreeExt
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnMemFreeExtCb_t)(
+    ze_mem_free_ext_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeModuleInspectLinkageExt
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_module_inspect_linkage_ext_params_t
+{
+    ze_linkage_inspection_ext_desc_t** ppInspectDesc;
+    uint32_t* pnumModules;
+    ze_module_handle_t** pphModules;
+    ze_module_build_log_handle_t** pphLog;
+} ze_module_inspect_linkage_ext_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeModuleInspectLinkageExt
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnModuleInspectLinkageExtCb_t)(
+    ze_module_inspect_linkage_ext_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricEdgeGetExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_edge_get_exp_params_t
+{
+    ze_fabric_vertex_handle_t* phVertexA;
+    ze_fabric_vertex_handle_t* phVertexB;
+    uint32_t** ppCount;
+    ze_fabric_edge_handle_t** pphEdges;
+} ze_fabric_edge_get_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricEdgeGetExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricEdgeGetExpCb_t)(
+    ze_fabric_edge_get_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricEdgeGetVerticesExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_edge_get_vertices_exp_params_t
+{
+    ze_fabric_edge_handle_t* phEdge;
+    ze_fabric_vertex_handle_t** pphVertexA;
+    ze_fabric_vertex_handle_t** pphVertexB;
+} ze_fabric_edge_get_vertices_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricEdgeGetVerticesExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricEdgeGetVerticesExpCb_t)(
+    ze_fabric_edge_get_vertices_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricEdgeGetPropertiesExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_edge_get_properties_exp_params_t
+{
+    ze_fabric_edge_handle_t* phEdge;
+    ze_fabric_edge_exp_properties_t** ppEdgeProperties;
+} ze_fabric_edge_get_properties_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricEdgeGetPropertiesExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricEdgeGetPropertiesExpCb_t)(
+    ze_fabric_edge_get_properties_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricVertexGetExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_vertex_get_exp_params_t
+{
+    ze_driver_handle_t* phDriver;
+    uint32_t** ppCount;
+    ze_fabric_vertex_handle_t** pphVertices;
+} ze_fabric_vertex_get_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricVertexGetExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricVertexGetExpCb_t)(
+    ze_fabric_vertex_get_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricVertexGetSubVerticesExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_vertex_get_sub_vertices_exp_params_t
+{
+    ze_fabric_vertex_handle_t* phVertex;
+    uint32_t** ppCount;
+    ze_fabric_vertex_handle_t** pphSubvertices;
+} ze_fabric_vertex_get_sub_vertices_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricVertexGetSubVerticesExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricVertexGetSubVerticesExpCb_t)(
+    ze_fabric_vertex_get_sub_vertices_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricVertexGetPropertiesExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_vertex_get_properties_exp_params_t
+{
+    ze_fabric_vertex_handle_t* phVertex;
+    ze_fabric_vertex_exp_properties_t** ppVertexProperties;
+} ze_fabric_vertex_get_properties_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricVertexGetPropertiesExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricVertexGetPropertiesExpCb_t)(
+    ze_fabric_vertex_get_properties_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function parameters for zeFabricVertexGetDeviceExp
+/// @details Each entry is a pointer to the parameter passed to the function;
+///     allowing the callback the ability to modify the parameter's value
+
+typedef struct _ze_fabric_vertex_get_device_exp_params_t
+{
+    ze_fabric_vertex_handle_t* phVertex;
+    ze_device_handle_t** pphDevice;
+} ze_fabric_vertex_get_device_exp_params_t;
+
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Callback function-pointer for zeFabricVertexGetDeviceExp
+/// @param[in] params Parameters passed to this instance
+/// @param[in] result Return value
+/// @param[in] pTracerUserData Per-Tracer user data
+/// @param[in,out] ppTracerInstanceUserData Per-Tracer, Per-Instance user data
+
+typedef void (ZE_APICALL *ze_pfnFabricVertexGetDeviceExpCb_t)(
+    ze_fabric_vertex_get_device_exp_params_t* params,
+    ze_result_t result,
+    void* pTracerUserData,
+    void** ppTracerInstanceUserData
+    );
+
 
 typedef enum _zel_tracer_reg_t
 {
@@ -1351,6 +1738,118 @@ zelTracerKernelSchedulingHintExpRegisterCallback(
     );
 
 
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerDevicePciGetPropertiesExtRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnDevicePciGetPropertiesExtCb_t pfnPciGetPropertiesExtCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerCommandListAppendImageCopyToMemoryExtRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnCommandListAppendImageCopyToMemoryExtCb_t pfnAppendImageCopyToMemoryExtCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerCommandListAppendImageCopyFromMemoryExtRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnCommandListAppendImageCopyFromMemoryExtCb_t pfnAppendImageCopyFromMemoryExtCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerImageGetAllocPropertiesExtRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnImageGetAllocPropertiesExtCb_t pfnGetAllocPropertiesExtCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerModuleInspectLinkageExtRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnModuleInspectLinkageExtCb_t pfnInspectLinkageExtCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerMemFreeExtRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnMemFreeExtCb_t pfnFreeExtCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricVertexGetExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricVertexGetExpCb_t pfnGetExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricVertexGetSubVerticesExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricVertexGetSubVerticesExpCb_t pfnGetSubVerticesExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricVertexGetPropertiesExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricVertexGetPropertiesExpCb_t pfnGetPropertiesExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricVertexGetDeviceExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricVertexGetDeviceExpCb_t pfnGetDeviceExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerDeviceGetFabricVertexExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnDeviceGetFabricVertexExpCb_t pfnGetFabricVertexExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricEdgeGetExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricEdgeGetExpCb_t pfnGetExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricEdgeGetVerticesExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricEdgeGetVerticesExpCb_t pfnGetVerticesExpCb
+    );
+
+
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zelTracerFabricEdgeGetPropertiesExpRegisterCallback(
+    zel_tracer_handle_t hTracer,
+    zel_tracer_reg_t callback_type,
+    ze_pfnFabricEdgeGetPropertiesExpCb_t pfnGetPropertiesExpCb
+    );
+
+
 ZE_APIEXPORT ze_result_t ZE_APICALL
 zelTracerResetAllCallbacks(zel_tracer_handle_t hTracer);
 
