@@ -1,11 +1,11 @@
 /*
  *
- * Copyright (C) 2019 Intel Corporation
+ * Copyright (C) 2019-2021 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  * @file zet_api.h
- * @version v1.1-r1.1.10
+ * @version v1.4-r1.4.1
  *
  */
 #ifndef _ZET_API_H
@@ -441,8 +441,8 @@ typedef struct _zet_debug_event_info_detached_t
 typedef struct _zet_debug_event_info_module_t
 {
     zet_module_debug_info_format_t format;          ///< [out] the module format
-    uint64_t moduleBegin;                           ///< [out] the begin address of the in-memory module
-    uint64_t moduleEnd;                             ///< [out] the end address of the in-memory module
+    uint64_t moduleBegin;                           ///< [out] the begin address of the in-memory module (inclusive)
+    uint64_t moduleEnd;                             ///< [out] the end address of the in-memory module (exclusive)
     uint64_t load;                                  ///< [out] the load address of the module on the device
 
 } zet_debug_event_info_module_t;
@@ -659,24 +659,12 @@ zetDebugWriteMemory(
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Supported device register set types.
-typedef enum _zet_debug_regset_type_t
-{
-    ZET_DEBUG_REGSET_TYPE_INVALID = 0,              ///< An invalid register set
-    ZET_DEBUG_REGSET_TYPE_GPR = 1,                  ///< The general purpose register set
-    ZET_DEBUG_REGSET_TYPE_ACC = 2,                  ///< The accumulator register set
-    ZET_DEBUG_REGSET_TYPE_ADDR = 3,                 ///< The address register set
-    ZET_DEBUG_REGSET_TYPE_FLAG = 4,                 ///< The flags register set
-    ZET_DEBUG_REGSET_TYPE_FORCE_UINT32 = 0x7fffffff
-
-} zet_debug_regset_type_t;
-
-///////////////////////////////////////////////////////////////////////////////
-/// @brief Supported device register set flags.
+/// @brief Supported general register set flags.
 typedef uint32_t zet_debug_regset_flags_t;
 typedef enum _zet_debug_regset_flag_t
 {
-    ZET_DEBUG_REGSET_FLAG_READ_ONLY = ZE_BIT(0),    ///< register set is read-only
+    ZET_DEBUG_REGSET_FLAG_READABLE = ZE_BIT(0),     ///< register set is readable
+    ZET_DEBUG_REGSET_FLAG_WRITEABLE = ZE_BIT(1),    ///< register set is writeable
     ZET_DEBUG_REGSET_FLAG_FORCE_UINT32 = 0x7fffffff
 
 } zet_debug_regset_flag_t;
@@ -688,11 +676,13 @@ typedef struct _zet_debug_regset_properties_t
 {
     zet_structure_type_t stype;                     ///< [in] type of this structure
     void* pNext;                                    ///< [in,out][optional] pointer to extension-specific structure
-    zet_debug_regset_type_t type;                   ///< [out] register set type
-    zet_debug_regset_flags_t flags;                 ///< [out] register set flags
+    uint32_t type;                                  ///< [out] device-specific register set type
+    uint32_t version;                               ///< [out] device-specific version of this register set
+    zet_debug_regset_flags_t generalFlags;          ///< [out] general register set flags
+    uint32_t deviceFlags;                           ///< [out] device-specific register set flags
     uint32_t count;                                 ///< [out] number of registers in the set
-    zet_value_type_t valueType;                     ///< [out] register value type
-    size_t valueSize;                               ///< [out] register value size in bytes
+    uint32_t bitSize;                               ///< [out] the size of a register in bits
+    uint32_t byteSize;                              ///< [out] the size required for reading or writing a register in bytes
 
 } zet_debug_regset_properties_t;
 
@@ -731,15 +721,13 @@ zetDebugGetRegisterSetProperties(
 ///     - ::ZE_RESULT_ERROR_DEVICE_LOST
 ///     - ::ZE_RESULT_ERROR_INVALID_NULL_HANDLE
 ///         + `nullptr == hDebug`
-///     - ::ZE_RESULT_ERROR_INVALID_ENUMERATION
-///         + `::ZET_DEBUG_REGSET_TYPE_FLAG < type`
 ///     - ::ZE_RESULT_ERROR_NOT_AVAILABLE
 ///         + the thread is running or unavailable
 ZE_APIEXPORT ze_result_t ZE_APICALL
 zetDebugReadRegisters(
     zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
     ze_device_thread_t thread,                      ///< [in] the thread identifier
-    zet_debug_regset_type_t type,                   ///< [in] register set type
+    uint32_t type,                                  ///< [in] register set type
     uint32_t start,                                 ///< [in] the starting offset into the register state area; must be less
                                                     ///< than ::zet_debug_regset_properties_t.count for the type
     uint32_t count,                                 ///< [in] the number of registers to read; start+count must be <=
@@ -756,15 +744,13 @@ zetDebugReadRegisters(
 ///     - ::ZE_RESULT_ERROR_DEVICE_LOST
 ///     - ::ZE_RESULT_ERROR_INVALID_NULL_HANDLE
 ///         + `nullptr == hDebug`
-///     - ::ZE_RESULT_ERROR_INVALID_ENUMERATION
-///         + `::ZET_DEBUG_REGSET_TYPE_FLAG < type`
 ///     - ::ZE_RESULT_ERROR_NOT_AVAILABLE
 ///         + the thread is running or unavailable
 ZE_APIEXPORT ze_result_t ZE_APICALL
 zetDebugWriteRegisters(
     zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
     ze_device_thread_t thread,                      ///< [in] the thread identifier
-    zet_debug_regset_type_t type,                   ///< [in] register set type
+    uint32_t type,                                  ///< [in] register set type
     uint32_t start,                                 ///< [in] the starting offset into the register state area; must be less
                                                     ///< than ::zet_debug_regset_properties_t.count for the type
     uint32_t count,                                 ///< [in] the number of registers to write; start+count must be <=
@@ -878,6 +864,7 @@ typedef enum _zet_metric_type_t
     ZET_METRIC_TYPE_FLAG = 5,                       ///< Metric type: flag
     ZET_METRIC_TYPE_RATIO = 6,                      ///< Metric type: ratio
     ZET_METRIC_TYPE_RAW = 7,                        ///< Metric type: raw
+    ZET_METRIC_TYPE_IP_EXP = 0x7ffffffe,            ///< Metric type: instruction pointer
     ZET_METRIC_TYPE_FORCE_UINT32 = 0x7fffffff
 
 } zet_metric_type_t;
@@ -1157,6 +1144,7 @@ zetMetricStreamerClose(
 ///         + `nullptr == hMetricStreamer`
 ///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
 ///         + `nullptr == pRawDataSize`
+///     - ::ZE_RESULT_WARNING_DROPPED_DATA - "Metric streamer data may have been dropped. Reduce sampling period."
 ZE_APIEXPORT ze_result_t ZE_APICALL
 zetMetricStreamerReadData(
     zet_metric_streamer_handle_t hMetricStreamer,   ///< [in] handle of the metric streamer
@@ -1376,7 +1364,7 @@ zetCommandListAppendMetricQueryEnd(
     zet_metric_query_handle_t hMetricQuery,         ///< [in] handle of the metric query
     ze_event_handle_t hSignalEvent,                 ///< [in][optional] handle of the event to signal on completion
     uint32_t numWaitEvents,                         ///< [in] must be zero
-    ze_event_handle_t* phWaitEvents                 ///< [in] must be nullptr
+    ze_event_handle_t* phWaitEvents                 ///< [in][mbz] must be nullptr
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1672,6 +1660,82 @@ zetTracerExpSetEnabled(
     ze_bool_t enable                                ///< [in] enable the tracer if true; disable if false
     );
 
+#if !defined(__GNUC__)
+#pragma endregion
+#endif
+// Intel 'oneAPI' Level-Zero Tool Experimental Extension for Calculating Multiple Metrics
+#if !defined(__GNUC__)
+#pragma region multiMetricValues
+#endif
+///////////////////////////////////////////////////////////////////////////////
+#ifndef ZET_MULTI_METRICS_EXP_NAME
+/// @brief Calculating Multiple Metrics Experimental Extension Name
+#define ZET_MULTI_METRICS_EXP_NAME  "ZET_experimental_calculate_multiple_metrics"
+#endif // ZET_MULTI_METRICS_EXP_NAME
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Calculating Multiple Metrics Experimental Extension Version(s)
+typedef enum _ze_calculate_multiple_metrics_exp_version_t
+{
+    ZE_CALCULATE_MULTIPLE_METRICS_EXP_VERSION_1_0 = ZE_MAKE_VERSION( 1, 0 ),///< version 1.0
+    ZE_CALCULATE_MULTIPLE_METRICS_EXP_VERSION_CURRENT = ZE_MAKE_VERSION( 1, 0 ),///< latest known version
+    ZE_CALCULATE_MULTIPLE_METRICS_EXP_VERSION_FORCE_UINT32 = 0x7fffffff
+
+} ze_calculate_multiple_metrics_exp_version_t;
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Calculate one or more sets of metric values from raw data.
+/// 
+/// @details
+///     - This function is similar to ::zetMetricGroupCalculateMetricValues
+///       except it may calculate more than one set of metric values from a
+///       single data buffer.  There may be one set of metric values for each
+///       sub-device, for example.
+///     - Each set of metric values may consist of a different number of metric
+///       values, returned as the metric value count.
+///     - All metric values are calculated into a single buffer; use the metric
+///       counts to determine which metric values belong to which set.
+///     - The application may call this function from simultaneous threads.
+/// 
+/// @returns
+///     - ::ZE_RESULT_SUCCESS
+///     - ::ZE_RESULT_ERROR_UNINITIALIZED
+///     - ::ZE_RESULT_ERROR_DEVICE_LOST
+///     - ::ZE_RESULT_ERROR_INVALID_NULL_HANDLE
+///         + `nullptr == hMetricGroup`
+///     - ::ZE_RESULT_ERROR_INVALID_ENUMERATION
+///         + `::ZET_METRIC_GROUP_CALCULATION_TYPE_MAX_METRIC_VALUES < type`
+///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
+///         + `nullptr == pRawData`
+///         + `nullptr == pSetCount`
+///         + `nullptr == pTotalMetricValueCount`
+ZE_APIEXPORT ze_result_t ZE_APICALL
+zetMetricGroupCalculateMultipleMetricValuesExp(
+    zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
+    zet_metric_group_calculation_type_t type,       ///< [in] calculation type to be applied on raw data
+    size_t rawDataSize,                             ///< [in] size in bytes of raw data buffer
+    const uint8_t* pRawData,                        ///< [in][range(0, rawDataSize)] buffer of raw data to calculate
+    uint32_t* pSetCount,                            ///< [in,out] pointer to number of metric sets.
+                                                    ///< if count is zero, then the driver shall update the value with the
+                                                    ///< total number of metric sets to be calculated.
+                                                    ///< if count is greater than the number available in the raw data buffer,
+                                                    ///< then the driver shall update the value with the actual number of
+                                                    ///< metric sets to be calculated.
+    uint32_t* pTotalMetricValueCount,               ///< [in,out] pointer to number of the total number of metric values
+                                                    ///< calculated, for all metric sets.
+                                                    ///< if count is zero, then the driver shall update the value with the
+                                                    ///< total number of metric values to be calculated.
+                                                    ///< if count is greater than the number available in the raw data buffer,
+                                                    ///< then the driver shall update the value with the actual number of
+                                                    ///< metric values to be calculated.
+    uint32_t* pMetricCounts,                        ///< [in,out][optional][range(0, *pSetCount)] buffer of metric counts per
+                                                    ///< metric set.
+    zet_typed_value_t* pMetricValues                ///< [in,out][optional][range(0, *pTotalMetricValueCount)] buffer of
+                                                    ///< calculated metrics.
+                                                    ///< if count is less than the number available in the raw data buffer,
+                                                    ///< then driver shall only calculate that number of metric values.
+    );
+
 #if !defined(__GNUC__)
 #pragma endregion
 #endif
